@@ -1,5 +1,9 @@
 import json
-import unittest
+import sys
+if sys.version_info < (2, 7):
+    import unittest2 as unittest
+else:
+    import unittest
 
 from ..exceptions import (
     JSONRPCError,
