@@ -1,4 +1,8 @@
-import unittest
+import sys
+if sys.version_info < (2, 7):
+    import unittest2 as unittest
+else:
+    import unittest
 from mock import MagicMock
 
 from ..manager import JSONRPCResponseManager
